import React, { useEffect, useMemo, useRef } from 'react'
import Taro from '@tarojs/taro'
import { View, Canvas } from '@tarojs/components'
import CodeText from './CodeText'
import { code128 } from './drawCode'
import './style.less'

const widthRatio = 0.7;
const barHeight = 80;

export default (props) => {

  const { code } = props

  const canvasRef = useRef()
  const ctxRef = useRef()

  const sysInfo = useMemo(() => {
    const { safeArea, pixelRatio } = Taro.getSystemInfoSync()

    return {
      width: safeArea.width,
      height: safeArea.height,
      dpr: pixelRatio,
    }
  }, [])
  const size = useMemo(() => ({ width: sysInfo.width * sysInfo.dpr * widthRatio, height: barHeight * sysInfo.dpr }), [sysInfo])

  const style = useMemo(() => ({ width: `${size.width}rpx`, height: `${size.height}rpx` }), [size])

  useEffect(() => {
    Taro.nextTick(() => {
      const query = Taro.createSelectorQuery()
      query.select('#barCodeCanvas').fields({ node: true }).exec((res) => {
        const canvas = res[0].node
        const ctx = canvas.getContext('2d')
        canvas.width = sysInfo.width
        canvas.height = sysInfo.height
        // ctx.scale(sysInfo.dpr, sysInfo.dpr)

        canvasRef.current = canvas;
        ctxRef.current = ctx;

        if (code) {
          code128(ctx, code, sysInfo.width, sysInfo.height);
        }
      })
    })
  }, [code, sysInfo])

  return (
    <View className='barcode-box' style={style}>
      <Canvas style={style} type='2d' id='barCodeCanvas'></Canvas>
      <CodeText code={code} />
    </View>
  )
}
